@@ -1,5 +1,6 @@
 from .lexical import LexicalTask
 from .semantic import SemanticTask
 from .syntactic import SyntacticTask
+from .prosody import ProsodicTask
 # todo find an alternative to make it more portable
-from .params import SLM21BenchmarkParameters
+from .params import SLM21BenchmarkParameters, ProsodyLMParameters
